==> hyperkyc_flutter-0.3.0.tar.gz: lib/hyperkyc_config.dart <==
import 'hyperkyc_flutter_constants.dart';

/// [HyperKycConfig] is used to launch HyperKyc
/// Create an instance of HyperKycConfig and call launch with it to start the workflow
class HyperKycConfig {
  /// [appId] to launch HyperKYC : Get this from Hyperverge team
  String? appId;

  /// [appKey] to launch HyperKYC : Get this from Hyperverge team
  String? appKey;

  /// [accessToken] to launch HyperKYC : Please contact Hyperverge team to understand how to generate HV accessToken
  String? accessToken;

  /// [workflowId] to launch HyperKYC : Each workflow that you have created in Hyperverge portal has a workflowId
  String? workflowId;

  /// [transactionId] to launch HyperKYC : Please contact Hyperverge team to understand more on sessions and transactionId
  String? transactionId;

  /// CustomInputs [inputs] to launch HyperKYC : If workflow requires any custom inputs, please pass those custom inputs here
  Map<String, String>? inputs;

  /// Default language code to be used for texts in HyperKyc flow
  String? defaultLangCode;

  /// Create HyperKycConfig instance from accessToken
  HyperKycConfig.fromAccessToken({
    required this.accessToken,
    required this.workflowId,
    required this.transactionId,
  });

  /// Create HyperKycConfig instance from appId, appKey
  HyperKycConfig.fromAppIdAppKey({
    required this.appId,
    required this.appKey,
    required this.workflowId,
    required this.transactionId,
  });

  /// Use [setInputs] to pass customInputs which are required by the workflow
  void setInputs({required Map<String, String> inputs}) {
    this.inputs = inputs;
  }

  /// Use [setDefaultLangCode] to pass customInputs which are required by the workflow
  void setDefaultLangCode({required String defaultLangCode}) {
    this.defaultLangCode = defaultLangCode;
  }

  /// Overridden [toString] method
  @override
  String toString() {
    return 'HyperKycConfig{appId: $appId, appKey: $appKey, accessToken: $accessToken, workflowId: $workflowId, transactionId: $transactionId, inputs: $inputs, defaultLangCode: $defaultLangCode}';
  }

  /// Convert HyperKycConfig object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.appId: appId,
      HyperKycConstants.appKey: appKey,
      HyperKycConstants.accessToken: accessToken,
      HyperKycConstants.workflowId: workflowId,
      HyperKycConstants.transactionId: transactionId,
      HyperKycConstants.inputs: inputs,
      HyperKycConstants.defaultLangCode: defaultLangCode,
    };
  }
}

==> hyperkyc_flutter-0.8.0.tar.gz: lib/hyperkyc_config.dart <==
import 'hyperkyc_flutter_constants.dart';

/// [HyperKycConfig] is used to launch HyperKyc
/// Create an instance of HyperKycConfig and call launch with it to start the workflow
class HyperKycConfig {
  /// [appId] to launch HyperKYC : Get this from Hyperverge team
  String? appId;

  /// [appKey] to launch HyperKYC : Get this from Hyperverge team
  String? appKey;

  /// [accessToken] to launch HyperKYC : Please contact Hyperverge team to understand how to generate HV accessToken
  String? accessToken;

  /// [workflowId] to launch HyperKYC : Each workflow that you have created in Hyperverge portal has a workflowId
  String? workflowId;

  /// [transactionId] to launch HyperKYC : Please contact Hyperverge team to understand more on sessions and transactionId
  String? transactionId;

  /// CustomInputs [inputs] to launch HyperKYC : If workflow requires any custom inputs, please pass those custom inputs here
  Map<String, String>? inputs;

  /// Default language code to be used for texts in HyperKyc flow
  String? defaultLangCode;

  /// Add metadata to [HyperKycConfig] which will be picked up by native SDKs
  final Map<String, String> _metadata = {};

  /// Create HyperKycConfig instance from accessToken
  HyperKycConfig.fromAccessToken({
    required this.accessToken,
    required this.workflowId,
    required this.transactionId,
  });

  /// Create HyperKycConfig instance from appId, appKey
  HyperKycConfig.fromAppIdAppKey({
    required this.appId,
    required this.appKey,
    required this.workflowId,
    required this.transactionId,
  });

  /// Use [setInputs] to pass customInputs which are required by the workflow
  void setInputs({required Map<String, String> inputs}) {
    this.inputs = inputs;
  }

  /// Use [setDefaultLangCode] to pass customInputs which are required by the workflow
  void setDefaultLangCode({required String defaultLangCode}) {
    this.defaultLangCode = defaultLangCode;
  }

  void _addMetadata({required Map<String, String> metadata}) {
    _metadata.addAll(metadata);
  }

  /// Overridden [toString] method
  @override
  String toString() {
    return 'HyperKycConfig{appId: $appId, appKey: $appKey, accessToken: $accessToken, workflowId: $workflowId, transactionId: $transactionId, inputs: $inputs, defaultLangCode: $defaultLangCode, metadata: $_metadata}';
  }

  /// Convert HyperKycConfig object to Map
  Map<String, dynamic> toMap() {
    _addMetadata(metadata: {
      'sdk-version': HyperKycConstants.hyperKycFlutterSDKVersion,
      'sdk-type': HyperKycConstants.hyperKycFlutterSDKType,
    });
    return {
      HyperKycConstants.appId: appId,
      HyperKycConstants.appKey: appKey,
      HyperKycConstants.accessToken: accessToken,
      HyperKycConstants.workflowId: workflowId,
      HyperKycConstants.transactionId: transactionId,
      HyperKycConstants.inputs: inputs,
      HyperKycConstants.defaultLangCode: defaultLangCode,
      HyperKycConstants.metadata: _metadata,
    };
  }
}
